@@ -27,6 +27,7 @@ class PdfPredictor():
         instruments_file_format="yaml",
         use_lstm=False,
         tessdata_dir=None,
+        tesseract_languages=["eng"],
         log_stream=sys.stdout,
         crop_to_top=False,
         crop_to_left=True,
@@ -43,6 +44,7 @@ class PdfPredictor():
             self.pdf = self.pdf.getvalue()
         self.use_lstm = use_lstm
         self.tessdata_dir = tessdata_dir
+        self.tesseract_languages = "+".join(tesseract_languages)
         self.log_stream = log_stream
         self.crop_to_top = crop_to_top
         self.crop_to_left = crop_to_left
@@ -84,6 +86,7 @@ class PdfPredictor():
                 timer = SimpleTimer()
                 tesserocr_kwargs = {
                     "psm": PSM.SPARSE_TEXT,
+                    "lang": self.tesseract_languages,
                 }
                 if self.use_lstm:
                     tesserocr_kwargs["oem"] = OEM.LSTM_ONLY
